# -*- coding: utf-8 -*-
# stuhl.py
"""Demo mit Klasse Schritte"""

from schritte import Schritte
from math import radians
from grafikfenster import *

### ---------------------------------------------------
class Stuhl():
    """Klasse Stuhl
    ermoeglicht das Zeichnen und Bearbeiten eines
    Stuhl-Symbols fuer den Raumplaner"""
    
    def __init__(self, sichtbar=False):
        """einfacher Konstruktor"""
        self.x=20
        self.y=20
        self.b=40
        self.t=40
        self.w=270
        self.f="blue"
        self.s=sichtbar
        if sichtbar: self.Zeige()
        
    def GibFigur(self):
        """definiert und transformiert die zu zeichnende Figur"""
        gc = Zeichenflaeche.GibZeichenflaeche().GibGC()
        path = gc.CreatePath()
        
        path.MoveToPoint(0, 0)
        path.AddLineToPoint(self.b, 0)
        path.AddLineToPoint(self.b*1.1, self.t)
        path.AddLineToPoint(-self.b*0.1, self.t)
        path.AddLineToPoint(0, 0)
        path.AddLineToPoint(0, -self.t*0.1)
        path.AddLineToPoint(self.b, -self.t*0.1)
        path.AddLineToPoint(self.b, 0)
        
        gc.PushState()
        gc.Translate(self.x+self.b/2, self.y+self.t/2)
        gc.Rotate(radians(self.w))
        gc.Translate(-self.b/2, -self.t/2)
        transformation = gc.GetTransform()
        gc.PopState()
        path.Transform(transformation)
        return path

    def GibFarbe(self):
        """Get-Methode fuer die Farbe"""
        return self.f
    
    def GibSichtbar(self):
        """Get-Methode fuer die Sichtbarkeit"""
        return self.s

    def BewegeHorizontal(self, weite):
        """Veraendernde Methode fuer die x-Position"""
        self.Verberge()
        self.x += weite
        self.Zeige()
    
    def BewegeVertikal(self, weite):
        """Veraendernde Methode fuer die y-Position"""
        self.Verberge()
        self.y += weite
        self.Zeige()
    
    def Drehe(self, winkel):
        """Veraendernde Methode fuer die Orientierung [Winkel]"""
        self.Verberge()
        self.w += winkel
        self.Zeige()

    def Verberge(self):
        """Veraendernde Methode fuer die Sichtbarkeit mit Wert False"""
        self.s = False
        Zeichenflaeche.GibZeichenflaeche().Entferne(self)

    def Zeige(self):
        """Veraendernde Methode fuer die Sichtbarkeit mit Wert True"""
        self.s = True
        Zeichenflaeche.GibZeichenflaeche().Zeichne(self)

### ---------------------------------------------------
class StuhlApp(wx.App):
    """Test-Anwendung speziell fuer Stuhl"""
    def OnInit(self):
        self.__fenster = GrafikFenster(None, "Raumplaner-Grafik")
        self.SetTopWindow(self.__fenster)
        self.__fenster.Show(True)
        self.__fenster.panel.Refresh()
        self.__fenster.ZeigeShellFrame()
        self.TestAnwendung()
        #self.__fenster.ZeigeFillingFrame()
        return True

    def TestAnwendung(self):
        # Allein fuer die Testanwendung:
        global stuhl
        print(__doc__)
        print('global: stuhl')
        stuhl=Stuhl(True)
        self.Schrittweise()
        
    def SchrittProzedur(self):
        '''definiert, was in jedem Schritt zu tun ist'''
        stuhl.BewegeHorizontal(3)
        stuhl.BewegeVertikal(1)
        stuhl.Drehe(10)

    def Schrittweise(self):
        '''verwendet die eigenstaendige Klasse Schritte'''
        self.schritte=Schritte(self, 36, self.SchrittProzedur)
        self.schritte.Start(100)


### ---------------------------------------------------
if __name__ == '__main__':
    app = StuhlApp(redirect=True)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
