# -*- coding: utf-8 -*-
# tisch.py
"""Demo mit Klasse Schritte"""

from schritte import Schritte
from math import radians
from grafikfenster import *

### ---------------------------------------------------
class Tisch():
    """Klasse Tisch
    ermoeglicht das Zeichnen und Bearbeiten eines
    Tisch-Symbols fuer den Raumplaner"""

    def __init__(self, sichtbar=False):
        """einfacher Konstruktor"""
        self.x=70
        self.y=10
        self.b=120
        self.t=60
        self.w=0
        self.f='red'
        self.s=sichtbar
        if sichtbar: self.Zeige()
        
    def GibFigur(self):
        """definiert und transformiert die zu zeichnende Figur"""
        gc = Zeichenflaeche.GibZeichenflaeche().GibGC()
        path = gc.CreatePath()
        
        path.AddRectangle(0, 0, self.b, self.t)
        
        gc.PushState()
        gc.Translate(self.x+self.b/2, self.y+self.t/2)
        gc.Rotate(radians(self.w))
        gc.Translate(-self.b/2, -self.t/2)
        transformation = gc.GetTransform()
        gc.PopState()
        path.Transform(transformation)
        return path

    def GibFarbe(self):
        """Get-Methode fuer die Farbe"""
        return self.f
    
    def GibSichtbar(self):
        """Get-Methode fuer die Sichtbarkeit"""
        return self.s

    def BewegeHorizontal(self, weite):
        """Veraendernde Methode fuer die x-Position"""
        self.Verberge()
        self.x += weite
        self.Zeige()
    
    def BewegeVertikal(self, weite):
        """Veraendernde Methode fuer die y-Position"""
        self.Verberge()
        self.y += weite
        self.Zeige()
    
    def Drehe(self, winkel):
        """Veraendernde Methode fuer die Orientierung [Winkel]"""
        self.Verberge()
        self.w += winkel
        self.Zeige()

    def Verberge(self):
        """Veraendernde Methode fuer die Sichtbarkeit mit Wert False"""
        self.s = False
        Zeichenflaeche.GibZeichenflaeche().Entferne(self)

    def Zeige(self):
        """Veraendernde Methode fuer die Sichtbarkeit mit Wert True"""
        self.s = True
        Zeichenflaeche.GibZeichenflaeche().Zeichne(self)

### ---------------------------------------------------
class TischApp(wx.App):
    """Test-Anwendung speziell fuer Tisch"""
    def OnInit(self):
        self.__fenster = GrafikFenster(None, "Raumplaner-Grafik")
        self.SetTopWindow(self.__fenster)
        self.__fenster.Show(True)
        self.__fenster.panel.Refresh()
        self.__fenster.ZeigeShellFrame()
        self.TestAnwendung()
        #self.__fenster.ZeigeFillingFrame()
        return True

    def TestAnwendung(self):
        # Allein fuer die Testanwendung:
        global tisch
        print(__doc__)
        print('global: tisch')
        tisch=Tisch(True)
        self.Schrittweise()

    def SchrittProzedur(self):
        '''definiert, was in jedem Schritt zu tun ist'''
        tisch.BewegeHorizontal(-1)
        tisch.BewegeVertikal(2)

    def Schrittweise(self):
        '''verwendet die eigenstaendige Klasse Schritte'''
        self.schritte=Schritte(self, 30, self.SchrittProzedur)
        self.schritte.Start(100)
        
        
### ---------------------------------------------------
if __name__ == '__main__':
    app = TischApp(redirect=True)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
